Index: third_party/WebKit/Source/modules/serviceworkers/WaitUntilObserver.cpp |
diff --git a/third_party/WebKit/Source/modules/serviceworkers/WaitUntilObserver.cpp b/third_party/WebKit/Source/modules/serviceworkers/WaitUntilObserver.cpp |
index f57dfb8c25efb7ec9cd0967946f684695fca4b9d..b02ff06454c394357bbef5c8cbe648f861275f04 100644 |
--- a/third_party/WebKit/Source/modules/serviceworkers/WaitUntilObserver.cpp |
+++ b/third_party/WebKit/Source/modules/serviceworkers/WaitUntilObserver.cpp |
@@ -86,12 +86,12 @@ WaitUntilObserver* WaitUntilObserver::create(ExecutionContext* context, |
void WaitUntilObserver::willDispatchEvent() { |
m_eventDispatchTime = WTF::currentTime(); |
- // When handling a notificationclick event, we want to allow one window to |
- // be focused or opened. These calls are allowed between the call to |
- // willDispatchEvent() and the last call to decrementPendingActivity(). If |
- // waitUntil() isn't called, that means between willDispatchEvent() and |
- // didDispatchEvent(). |
- if (m_type == NotificationClick) |
+ // When handling a notificationclick or paymentrequest event, we want to |
+ // allow one window to be focused or opened. These calls are allowed between |
+ // the call to willDispatchEvent() and the last call to |
+ // decrementPendingActivity(). If waitUntil() isn't called, that means |
+ // between willDispatchEvent() and didDispatchEvent(). |
+ if (m_type == NotificationClick || m_type == PaymentRequest) |
m_executionContext->allowWindowInteraction(); |
incrementPendingActivity(); |